@@ -11,13 +11,20 @@
 #' @param pattern an optional regular expression.  Only names matching
 #' \code{pattern} are returned.  \code{\link[utils]{glob2rx}} can be used to
 #' convert wildcard patterns to regular expressions.
-#' @param order_by a character, order the results by \dQuote{Size} (default),
-#' \dQuote{Type}, \dQuote{Rows}, or \dQuote{Columns}.
+#' @param order_by a character, order the results by \dQuote{object},
+#' \dQuote{size} (default), \dQuote{class}, \dQuote{rows}, or \dQuote{columns}.
 #' @param decreasing logical, defaults to \code{TRUE}, decreasing order? passed
 #' to \code{\link[base]{order}}.
-#' @param head logical, if \code{TRUE} then only return the first \code{n}
-#' objects per \code{order_by} and \code{decreasing}.
-#' @param n number of rows to return, ignored if \code{head = FALSE}.
+#'
+#' @return a data.frame with columns
+#' \itemize{
+#'  \item object: name of the object
+#'  \item class: class, or mode if class is not present, of the object
+#'  \item size: approximate size, in bytes, of the object in memory
+#'  \item rows: number of rows for data.frames or matrices, or the number of
+#'  elements for a list like structure
+#'  \item columns: number of columns for data.frames or matrices
+#' }
 #'
 #' @examples
 #' # View your current workspace
@@ -39,10 +46,9 @@
 #'
 #' ls(e)
 #' ll(e)
-#' ll(e, head = TRUE)
 #'
 #' @export
-ll <- function (pos = 1, pattern, order_by = "Size", decreasing = TRUE, head = FALSE, n = 5) {
+ll <- function (pos = 1, pattern, order_by = "size", decreasing = order_by %in% c("size", "rows", "columns")) {
     napply <- function(names, fn) sapply(names, function(x)
                                          fn(get(x, pos = pos)))
     names <- ls(pos = pos, pattern = pattern)
@@ -56,13 +62,16 @@ ll <- function (pos = 1, pattern, order_by = "Size", decreasing = TRUE, head = F
     obj.dim <- t(napply(names, function(x) as.numeric(dim(x))[1:2]))
     vec <- is.na(obj.dim)[, 1] & (obj.type != "function")
     obj.dim[vec, 1] <- napply(names, length)[vec]
-    out <- data.frame(obj.type, obj.size, obj.dim)
-    names(out) <- c("Type", "Size", "Rows", "Columns")
+    out <- data.frame("object" = names,
+                      "class" = obj.type,
+                      "size"  = obj.size,
+                      "rows"  = obj.dim[, 1],
+                      "columns" = obj.dim[, 2])
 
     out <- out[order(out[[order_by]], decreasing = decreasing), ]
 
-    if (head)
-        out <- head(out, n)
+    rownames(out) <- NULL
+
     out
 }
 
